
var author              = "Patrick Thompson";
var contentFlag         = CONTENT | PROFILE_CHROME;
var localeFlag            = LOCALE | PROFILE_CHROME;
var skinFlag            = SKIN | PROFILE_CHROME;
var displayName         = "InspectorWidget";
var locales             = new Array("en-US", "fr-FR");
var folder              = getFolder("Current User", "chrome");
var name                = "InspectorWidget";
var version             = "2.11.20070812";
var IWjarName           = "inspectorwidget.jar";
var existsInApplication = File.exists(getFolder(getFolder("Chrome"), IWjarName));
var existsInProfile     = File.exists(getFolder(folder, IWjarName));

// this function verifies disk space in kilobytes
function verifyDiskSpace(dirPath, spaceRequired)
{
  var spaceAvailable;

  // Get the available disk space on the given path
  spaceAvailable = fileGetDiskSpaceAvailable(dirPath);

  // Convert the available disk space into kilobytes
  spaceAvailable = parseInt(spaceAvailable / 1024);

  // do the verification
  if(spaceAvailable < spaceRequired)
  {
    logComment("Insufficient disk space: " + dirPath);
    logComment("  required : " + spaceRequired + " K");
    logComment("  available: " + spaceAvailable + " K");
    return(false);
  }

  return(true);
}

// this function deletes a file if it exists
function deleteThisFile(dirKey, file)
{
  var fFileToDelete;

  fFileToDelete = getFolder(dirKey, file);
  logComment("File to delete: " + fFileToDelete);
  if(File.isFile(fFileToDelete))
  {
    File.remove(fFileToDelete);
    return(true);
  }
  else
    return(false);
}

// this function deletes a folder if it exists
function deleteThisFolder(dirKey, folder, recursiveDelete)
{
  var fToDelete;

  if(typeof recursiveDelete == "undefined")
    recursiveDelete = true;

  fToDelete = getFolder(dirKey, folder);
  logComment("folder to delete: " + fToDelete);
  if(File.isDirectory(fToDelete))
  {
    File.dirRemove(fToDelete, recursiveDelete);
    return(true);
  }
  else
    return(false);
}

/* Though the XPI format is by definition cross-platform, the files you
 * distribute within it may need to be installed on a per-platform basis.
 * The platform can be retrieved using the platform property of the
 * Install object or the getFolder function.
 */
function getPlatform()
{
  var platformStr;
  var platformNode;

  if('platform' in Install)
  {
    platformStr = new String(Install.platform);

    if (!platformStr.search(/^Macintosh/))
      platformNode = 'mac';
    else if (!platformStr.search(/^Win/))
      platformNode = 'win';
    else if (!platformStr.search(/^OS\/2/))
      platformNode = 'win';
    else
      platformNode = 'unix';
  }
  else
  {
    var fOSMac  = getFolder("Mac System");
    var fOSWin  = getFolder("Win System");

    logComment("fOSMac: "  + fOSMac);
    logComment("fOSWin: "  + fOSWin);

    if(fOSMac != null)
      platformNode = 'mac';
    else if(fOSWin != null)
      platformNode = 'win';
    else
      platformNode = 'unix';
  }

  return platformNode;
}

// INSTALLATION PROCESS BEGINS HERE!

var err = initInstall(displayName, name, version);
logComment("initInstall: " + err);

var messages = loadResources("install.properties");

/*
 * Comment out platform check since button should be platform independent.
 *
if (getPlatform() != 'win')
{
    alert(displayName + " " + messages.notwin_en + " " + getPlatform());
}
else
{
 */

/*
 * Used if extension can be installed either locally or globally
 */
    if(existsInApplication || (!existsInProfile && !confirm(messages.installDest_en)))
    {
        contentFlag = CONTENT | DELAYED_CHROME;
        localeFlag = LOCALE | DELAYED_CHROME;
        skinFlag    = SKIN | DELAYED_CHROME;
        folder      = getFolder("Chrome");
    }

    err = setPackageFolder(folder);
    logComment("setPackageFolder: " + err);

    err = addFile(author, version, "chrome/" + IWjarName, folder, null);
    logComment("addFile(chrome/" + IWjarName + "): " + err);

    var IWFolder = getFolder(folder, IWjarName);

    registerChrome(contentFlag, IWFolder, "content/inspectorwidget/");
    registerChrome(skinFlag, IWFolder, "skin/classic/inspectorwidget/");
    registerChrome(skinFlag, IWFolder, "skin/aluminumalloy/inspectorwidget/");
    registerChrome(skinFlag, IWFolder, "skin/skypilot/inspectorwidget/");
    registerChrome(skinFlag, IWFolder, "skin/toyfactory/inspectorwidget/");
    for (var i = 0; i < locales.length; i++) {
      registerChrome(localeFlag, IWFolder, "locale/" + locales[i] + "/inspectorwidget/");
    }
    err = getLastError();
    if (err==SUCCESS)
    {

/*
 * Delete XUL cache so IW toolbar icon will be included on startup.
 */
        err = File.remove(getFolder("Current User", "XUL.mfl"));
        logComment("File.remove: " + err);

        var tellReboot = false;
        err = performInstall();
        logComment("performInstall() returned: " + err);
        if (err == REBOOT_NEEDED)
        {
           tellReboot = true;
           resetError();
           err = 0;
        }
        if (err == SUCCESS)
        {
           if (tellReboot)
           {
               alert(displayName + " " + messages.success_reboot_en);
           }
           else
           {
               alert(displayName + " " +  messages.success_en);
           }
        }
        else
        {
               logComment("cancelInstall due to error: " + err);
               alert(displayName + " " +  messages.fail_en + " " +  err);
        }
    } 
    else
    {
        logComment("cancelInstall due to error: " + err);
        cancelInstall(err);
        alert(displayName + " " +  messages.cancel_en + " " +  err);
    }

/*
 * Comment out platform check since button should be platform independent.
 *
}
 */
